package com.rcpquickstart.videoplayer;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.net.URI;

import javax.swing.JPanel;
import javax.swing.JRootPane;

import org.eclipse.swt.SWT;
import org.eclipse.swt.awt.SWT_AWT;
import org.eclipse.swt.widgets.Composite;

import com.sun.media.jmc.JMediaPane;

/**
 * Control that represents the video display only. It does not represent any
 * controls related to video playback (play, pause buttons, etc.). The goal of
 * this control is to minimize the SWT/AWT interaction, limiting the AWT
 * dependency to the video display only.
 * 
 * @author Patrick Paulin
 * 
 */
public class VideoControl {

	private JMediaPane player;
	private JRootPane pane;

	public VideoControl(Composite parent) {
		Composite composite = new Composite(parent, SWT.EMBEDDED
				| SWT.NO_BACKGROUND);

		/* This AWT construction is meant to reduce flicker as much as possible. */
		Frame frame = SWT_AWT.new_Frame(composite);
		JPanel panel = new JPanel(new BorderLayout());
		frame.add(panel);
		this.pane = new JRootPane();
		panel.add(this.pane);
	}

	public void play() {
		if (this.player != null) {
			this.player.play();
		}
	}

	public void stop() {
		if (this.player != null) {
			this.player.stop();
		}
	}

	public void pause() {
		if (this.player != null) {
			this.player.pause();
		}
	}

	/**
	 * Change the source URI. I've had no luck using the setSource method to
	 * switch the URI of the media pane. The next URI loads but only the sound
	 * plays. As a workaround, I've chosen to recreate a new media pane for
	 * every video.
	 * 
	 * Maybe I'm doing something wrong?
	 * 
	 * @param uri
	 */
	public void setSource(URI uri) {

		if (this.player != null) {
			this.pane.remove(this.player);
		}
		try {
			this.player = new JMediaPane(uri);
		} catch (Exception e) {
			e.printStackTrace();
		}
		this.pane.setContentPane(player);
		this.pane.revalidate();
	}

	public boolean isPlaying() {
		if (this.player != null) {
			return this.player.isPlaying();
		}
		return false;
	}
}
